# WEB+DB PRESS Vol.124 特集1「詳解Visual Studio Code」サンプルコード

技術評論社刊「WEB+DB PRESS Vol.124」の特集1「詳解Visual Studio Code」（上田裕己著）のサンプルコードです。

それぞれ、`02`、`04`、`05`フォルダは各章に対応しています。

## 02：自分だけのVisual Studio Codeにカスタマイズ

`.vscode`以下に本特集執筆で利用したスニペットファイル`tasks.json`と`markdown.code-snippets`を置いています。
いずれも`.vscode`ごとワークスペースに置くことで利用できます。

`markdown.code-snippets`は適当なファイルを開き、`signature`などと入力すれば補完が実行されます。

`tasks.json`は<kbd>Shift</kbd>+<kbd>Ctrl</kbd>+<kbd>B</kbd>（macOS：<kbd>shift</kbd>+<kbd>command</kbd>+<kbd>B</kbd>）でタスクリストをよびだし、「echo Hello」を選択するとウィンドウを表示できます。

## 04：ビルド、デバッグ、実行

Javaの章で利用したファイルを`java`、Pythonファイルを`python`以下に置いています。

### java

`Hello, World!`と`1 + 2 + 3`の結果を出力するプログラムです。
実行にはvscodeで`04/java/hello-java`を開き、`App.java`の1-2行目の間にある`Run|Debug`ボタンをクリックしてください。

以下は構造図です。

```md
./04/java/hello-java
├── lib            // 依存ライブラリ格納フォルダ
├── src            // ソースコード格納フォルダ
│   └── App.java   // Javaのソースコード
└── README.md      // Javaプロジェクト開発のヘルプ
```

### python

* `hello.py`：`Hello Python`と出力するプログラム
* `standardplot.py`：波画像を表示するプログラム

それぞれ

```sh
$ python3 ./04/python/hello.py
```

```
$ python3 ./04/python/statdardplot.py
```

で実行できます。
また、`statdardplot.py`はPythonのCodeLensからも実行可能です。

## 05：Visual Studio Code拡張機能および本体の開発

hello-vscodeをVSCodeで開くと利用できます。

```sh
$ npm install
```

を実行し、F5キーでテスト可能です。

以下は構造図です。

```md
./05/hello-vscode
├── .vscode               // 拡張機能開発に使うVSCodeファイル
│   ├── extensions.json   // 開発で利用する拡張機能、標準ではESLintを利用
│   ├── launch.json       // 拡張機能のデバッグ用コマンドを扱うファイル
│   ├── setting.json      // プロジェクトの設定。
│   └── tasks.json        // ビルドおよびコンパイル用
|── node_modules          // 依存パッケージ格納フォルダ
|── out                   // コンパイルで生成したファイル格納フォルダ
├── src
│   ├── extension.ts  // 拡張機能のソースコード
│   └─test
│      ├── suite
│      │    ├── extension.test.ts // ユニットテストコード
│      │    └── index.ts          // ユニットテスト実行用コード
│      └── runTest.ts             // テストコードのメインファイル
├── .eslintrc.json        // ESLintの設定ファイル
├── .gitignore            // Gitで管理しないファイルを定義する
├── .vscodeignore         // 拡張機能のパッケージ時に除外するファイルを定義する
├── CHANGELOG.md          // ユーザー向けに拡張機能の更新情報
├── package-lock.json     // node_modulesの内容を再現するための依存関係リスト
├── package.json      // 依存関係、バージョン、仕様を管理する
├── README.md             // 拡張機能の説明書
├── tsconfig.json         // TypeScriptのコンパイル設定
└── vsc-extension-quickstart.md   // 拡張機能開発のHOWTOドキュメント
```
